use std::fmt::Display;

use binrw::{BinRead, BinWrite};

use crate::{
    field_of::FieldOf,
    types::{Field, Point, F64, U32},
};

use super::ObjectBase;

#[derive(BinRead, BinWrite, Debug)]
pub struct Circle {
    pub base: ObjectBase,
    #[brw(magic(6u32))] // Number of following fields in struct
    pub origin: FieldOf<Point>,
    pub radius: F64,
    pub start_angle: F64, // Radians
    pub clockwise: U32,
    _unknown_1: [Field; 2],
}

impl Display for Circle {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(
            f,
            "{} origin: {}, radius: {:.2}, start_angle: {:.2}, clockwise: {}",
            self.base, *self.origin, *self.radius, *self.start_angle, *self.clockwise
        )
    }
}
