use std::fmt::Display;

use binrw::{BinRead, BinWrite};

use crate::{
    field_of::FieldOf,
    types::{Field, Point, F64, U32},
};

use super::ObjectBase;

#[derive(BinRead, BinWrite, Debug)]
pub struct Ellipse {
    pub base: ObjectBase,
    #[brw(magic(8u32))] // Number of following fields in struct
    pub clockwise: U32,
    pub corner_a: FieldOf<Point>,
    pub corner_b: FieldOf<Point>,
    pub start_angle: F64, // Radians
    pub end_angle: F64,   // Radians
    _unknown_1: [Field; 2],
    pub open_curve: U32,
}

impl Display for Ellipse {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(
            f,
            "{} corners: {{{}, {}}}, start angle: {:.2}, end angle: {:.2}, clockwise: {}, open: {}",
            self.base,
            *self.corner_a,
            *self.corner_b,
            *self.start_angle,
            *self.end_angle,
            *self.clockwise,
            *self.open_curve
        )
    }
}
