use std::fmt::Display;

use binrw::{BinRead, BinWrite};

use crate::{
    field_of::FieldOf,
    types::{Field, Point, F64, U32},
};

use super::ObjectBase;

#[derive(BinRead, BinWrite, Debug)]
pub struct Polygon {
    pub base: ObjectBase,
    #[brw(magic(10u32))] // Number of following fields in struct
    pub invert_shape: U32,
    pub corner_a: FieldOf<Point>,
    pub corner_b: FieldOf<Point>,
    pub offset_cx: F64,
    pub offset_cy: F64,
    pub offset_dx: F64,
    pub offset_dy: F64,
    pub edges: U32,
    _unknown_1: [Field; 2],
}

impl Display for Polygon {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(
            f,
            "{} corners: {{{}, {}}}, offsets: ({:.2}, {:.2}, {:.2}, {:.2}), edges: {}, invert: {}",
            self.base,
            *self.corner_a,
            *self.corner_b,
            *self.offset_cx,
            *self.offset_cy,
            *self.offset_dx,
            *self.offset_dy,
            *self.edges,
            *self.invert_shape
        )
    }
}
