use std::fmt::Display;

use binrw::{BinRead, BinWrite};

use crate::{
    field_of::FieldOf,
    types::{Field, Point, F64},
};

use super::ObjectBase;

#[derive(BinRead, BinWrite, Debug)]
pub struct Rectangle {
    pub base: ObjectBase,
    #[brw(magic(8u32))] // Number of following fields in struct
    pub corner_a: FieldOf<Point>,
    pub corner_b: FieldOf<Point>,
    pub round_bottom_left: F64,
    pub round_bottom_right: F64,
    pub round_top_right: F64,
    pub round_top_left: F64,
    _unknown_1: [Field; 2],
}

impl Display for Rectangle {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(
            f,
            "{} corners: {{{}, {}}}, rounding: ({:.2}, {:.2}, {:.2}, {:.2})",
            self.base,
            *self.corner_a,
            *self.corner_b,
            *self.round_top_left,
            *self.round_top_right,
            *self.round_bottom_left,
            *self.round_bottom_right
        )
    }
}
